powered by
Methods to visualize and convert OpenSpecy objects.
OpenSpecy
# S3 method for OpenSpecy head(x, ...)# S3 method for OpenSpecy print(x, ...)# S3 method for OpenSpecy plot( x, offset = 0, legend_var = NULL, pallet = rainbow, main = "Spectra Plot", xlab = "Wavenumber (1/cm)", ylab = "Intensity (a.u.)", ... )# S3 method for OpenSpecy summary(object, ...)# S3 method for OpenSpecy as.data.frame(x, ...)# S3 method for OpenSpecy as.data.table(x, ...)
# S3 method for OpenSpecy print(x, ...)
# S3 method for OpenSpecy plot( x, offset = 0, legend_var = NULL, pallet = rainbow, main = "Spectra Plot", xlab = "Wavenumber (1/cm)", ylab = "Intensity (a.u.)", ... )
# S3 method for OpenSpecy summary(object, ...)
# S3 method for OpenSpecy as.data.frame(x, ...)
# S3 method for OpenSpecy as.data.table(x, ...)
head(), print(), and summary() return a textual representation of an OpenSpecy object. plot() and lines() return a plot. as.data.frame() and as.data.table() convert OpenSpecy
head()
print()
summary()
plot()
lines()
as.data.frame()
as.data.table()
objects into tabular data.
an OpenSpecy object.
Numeric value for vertical offset of each successive spectrum. Defaults to 1. If 0, all spectra share the same baseline.
Character string naming a metadata column in x$metadata that labels/colors each spectrum. If NULL, spectra won't be labeled.
x$metadata
The base R graphics color pallet function to use. If NULL will default to all black.
Plot text for title.
Plot x axis text
Plot y axis text
further arguments passed to the respective default method.
Zacharias Steinmetz, Win Cowger
head() shows the first few lines of an OpenSpecy object. print() prints the contents of an OpenSpecy object. plot() produces a plot() of an OpenSpecy
head(), print(), summary(), matplot(), and matlines(), as.data.frame(), as.data.table()
matplot()
matlines()
data("raman_hdpe") # Printing the OpenSpecy object print(raman_hdpe) # Displaying the first few lines of the OpenSpecy object head(raman_hdpe) # Plotting the spectra plot(raman_hdpe)
Run the code above in your browser using DataLab