Converts reflectance or transmittance intensity units to absorbance units.
adj_intens(x, ...)# S3 method for default
adj_intens(x, ...)
# S3 method for OpenSpecy
adj_intens(x, type = "none", make_rel = TRUE, ...)
adj_intens() returns a data frame containing two columns
named "wavenumber" and "intensity".
a list object of class OpenSpecy.
a character string specifying whether the input spectrum is
in absorbance units ("none", default) or needs additional conversion
from "reflectance" or "transmittance" data.
logical; if TRUE spectra are automatically normalized
with make_rel().
further arguments passed to submethods; this is
to adj_neg() for adj_intens() and
to conform_res() for conform_intens().
Win Cowger, Zacharias Steinmetz
Many of the Open Specy functions will assume that the spectrum is in
absorbance units. For example, see subtr_baseline().
To run those functions properly, you will need to first convert any spectra
from transmittance or reflectance to absorbance using this function.
The transmittance adjustment uses the \(log(1 / T)\)
calculation which does not correct for system and particle characteristics.
The reflectance adjustment uses the Kubelka-Munk equation
\((1 - R)^2 / 2R\). We assume that the reflectance intensity
is a percent from 1-100 and first correct the intensity by dividing by 100
so that it fits the form expected by the equation.
subtr_baseline() for spectral background correction.
data("raman_hdpe")
adj_intens(raman_hdpe)
Run the code above in your browser using DataLab