Read file(s) acquired with a Bruker Vertex FTIR Instrument. This function
is basically a fork of opus_read() from
https://github.com/pierreroudier/opusreader.
read_opus(
file,
metadata = list(file_name = basename(file), user_name = NULL, contact_info = NULL,
organization = NULL, citation = NULL, spectrum_type = NULL, spectrum_identity = NULL,
material_form = NULL, material_phase = NULL, material_producer = NULL,
material_purity = NULL, material_quality = NULL, material_color = NULL,
material_other = NULL, cas_number = NULL, instrument_used = NULL,
instrument_accessories = NULL, instrument_mode = NULL, spectral_resolution = NULL,
laser_light_used = NULL, number_of_accumulations = NULL,
total_acquisition_time_s = NULL, data_processing_procedure = NULL,
level_of_confidence_in_identification = NULL, other_info = NULL, license =
"CC BY-NC"),
type = "spec",
digits = 1L,
atm_comp_minus4offset = FALSE
)An OpenSpecy object.
character vector with path to file(s).
a named list of the metadata; see
as_OpenSpecy() for details.
character vector of spectra types to extract from OPUS binary
file. Default is "spec", which will extract the final spectra, e.g.
expressed in absorbance (named AB in Bruker OPUS programs). Possible
additional values for the character vector supplied to type are
"spec_no_atm_comp" (spectrum of the sample without compensation for
atmospheric gases, water vapor and/or carbon dioxide),
"sc_sample" (single channel spectrum of the sample measurement), "sc_ref"
(single channel spectrum of the reference measurement),
"ig_sample" (interferogram of the sample measurement) and "ig_ref"
(interferogram of the reference measurement).
Integer that specifies the number of decimal places used to round the wavenumbers (values of x-variables).
Logical whether spectra after atmospheric
compensation are read with an offset of -4 bytes from Bruker OPUS files;
default is FALSE.
Philipp Baumann, Zacharias Steinmetz, Win Cowger
The type of spectra returned by the function when using
type = "spec" depends on the setting of the Bruker instrument: typically,
it can be either absorbance or reflectance.
The type of spectra to extract from the file can also use Bruker's OPUS software naming conventions, as follows:
ScSm corresponds to sc_sample
ScRf corresponds to sc_ref
IgSm corresponds to ig_sample
IgRf corresponds to ig_ref
read_spec() for reading .y(a)ml, .json, or .rds (OpenSpecy)
files;
read_text(), read_asp(), read_spa(),
read_spc(), and read_jdx() for text files, .asp,
.spa, .spa, .spc, and .jdx formats, respectively;
read_text() for reading .dat (ENVI) files;
read_zip() and read_any() for wrapper functions;
read_opus_raw();
read_extdata("ftir_ps.0") |> read_opus()
Run the code above in your browser using DataLab