| run_app | R Documentation |
This wrapper function starts the graphical user interface of Open Specy.
run_app(
path = "system",
log = TRUE,
ref = NULL,
check_local = TRUE,
test_mode = FALSE,
launch.browser = getOption("shiny.launch.browser", interactive()),
...
)
path |
Shiny app directory, or |
log |
logical; enables/disables Shiny logging to |
ref |
retained for compatibility with older releases; ignored because the app is bundled with the package. |
check_local |
retained for compatibility with older releases; ignored
because |
test_mode |
logical; for internal testing only. |
launch.browser |
option for |
... |
arguments passed to |
By default, run_app() launches the Shiny app bundled with the installed
OpenSpecy package at system.file("shiny", package = "OpenSpecy").
Historical GitHub download support has been removed so package installs use
the same app files offline. Set path to an explicit app directory when
testing a local Shiny app during development.
This function normally does not return any value, see shiny::runApp().
In test_mode, it invisibly returns the resolved app path.
Win Cowger, Zacharias Steinmetz, Garth Covernton
shiny::runApp()
## Not run:
run_app()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.